<?php

// Set a maximum width for Oembedded objects
if ( ! isset( $content_width ) ) $content_width = 900;

function ractopress_setup() {
	

	// This theme styles the visual editor with editor-style.css to match the theme style.
	add_editor_style();

	// Adds RSS feed links to <head> for posts and comments.
	add_theme_support( 'automatic-feed-links' );

	// This theme supports a variety of post formats.
	add_theme_support( 'post-formats', array( 'aside', 'image', 'link', 'quote', 'status' ) );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menu( 'primary', __( 'Primary Menu', 'ractopress' ) );

	// This theme uses a custom image size for featured images, displayed on "standard" posts.
	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 624, 9999 ); // Unlimited height, soft crop
}
add_action( 'after_setup_theme', 'ractopress_setup' );

/*
	 * Adds JavaScript to pages with the comment form to support
	 * sites with threaded comments (when in use).
	 */
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) )
		wp_enqueue_script( 'comment-reply' );
		
if ( ! function_exists( 'ractopress_comment' ) ) :
/**
 * Template for comments and pingbacks.
 *
 * To override this walker in a child theme without modifying the comments template
 * simply create your own ractopress_comment(), and that function will be used instead.
 *
 * Used as a callback by wp_list_comments() for displaying the comments.
 *
 */
function ractopress_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
		// Display trackbacks differently than normal comments.
	?>
	<li <?php comment_class(); ?> id="comment-<?php comment_ID(); ?>">
		<p><?php _e( 'Pingback:', 'ractopress' ); ?> <?php comment_author_link(); ?> <?php edit_comment_link( __( '(Edit)', 'ractopress' ), '<span class="edit-link">', '</span>' ); ?></p>
	<?php
			break;
		default :
		// Proceed with normal comments.
		global $post;
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
		<article id="comment-<?php comment_ID(); ?>" class="comment">
			<header class="comment-meta comment-author vcard">
				<?php
					echo get_avatar( $comment, 44 );
					printf( '<cite class="fn">%1$s %2$s</cite>',
						get_comment_author_link(),
						// If current post author is also comment author, make it known visually.
						( $comment->user_id === $post->post_author ) ? '<span> ' . __( 'Post author', 'ractopress' ) . '</span>' : ''
					);
					printf( '<a href="%1$s"><time datetime="%2$s">%3$s</time></a>',
						esc_url( get_comment_link( $comment->comment_ID ) ),
						get_comment_time( 'c' ),
						/* translators: 1: date, 2: time */
						sprintf( __( '%1$s at %2$s', 'ractopress' ), get_comment_date(), get_comment_time() )
					);
				?>
			</header><!-- .comment-meta -->

			<?php if ( '0' == $comment->comment_approved ) : ?>
				<p class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'ractopress' ); ?></p>
			<?php endif; ?>

			<section class="comment-content comment">
				<?php comment_text(); ?>
				<?php edit_comment_link( __( 'Edit', 'ractopress' ), '<p class="edit-link">', '</p>' ); ?>
			</section><!-- .comment-content -->

			<div class="reply">
				<?php comment_reply_link( array_merge( $args, array( 'reply_text' => __( 'Reply', 'ractopress' ), 'after' => ' <span>&darr;</span>', 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
			</div><!-- .reply -->
		</article><!-- #comment-## -->
	<?php
		break;
	endswitch; // end comment_type check
}
endif;

/**
 * Registers our main widget area and the front page widget areas.
 */
 
function ractopress_widgets_init() {
register_sidebar( array(
'name'=>'Sidebar',
'before_widget' => '',
'after_widget' => '',
'before_title' => '<h3>',
'after_title' => '</h3>',
));
}
add_action( 'widgets_init', 'ractopress_widgets_init' );


// Set a maximum width for Oembedded objects

// Randomly chosen placeholder text for post/page edit screen
function ractopress_writing_encouragement( $content ) {
	global $post_type;
	if($post_type == "post"){
	$encArray = array(
		// Placeholders for the posts editor
		"Test post message one.",
		"Test post message two.",
		"<h1>Test post heading!</h1>"
		);
		return $encArray[array_rand($encArray)];
	}
	else{ $encArray = array(
		// Placeholders for the pages editor
		"Test page message one.",
		"Test page message two.",
		"<h1>Test Page Heading</h1>"
		);
		return $encArray[array_rand($encArray)];
	}
}
add_filter( 'default_content', 'ractopress_writing_encouragement' );


//change amount of posts on the search page - set here to 100
function ractopress_search_results_per_page( $query ) {
	global $wp_the_query;
	if ( ( ! is_admin() ) && ( $query === $wp_the_query ) && ( $query->is_search() ) ) {
	$query->set( 'ractopress_search_results_per_page', 100 );
	}
	return $query;
}
add_action( 'pre_get_posts',  'ractopress_search_results_per_page'  );


//create a permalink after the excerpt
function ractopress_replace_excerpt($content) {
	return str_replace('[...]',
		'<a class="readmore" href="'. get_permalink() .'">Continue Reading</a>',
		$content
	);
}
add_filter('the_excerpt', 'ractopress_replace_excerpt');


// Stop images getting wrapped up in p tags when they get dumped out with the_content() for easier theme styling
function ractopress_remove_img_ptags($content){
	return preg_replace('/<p>\s*(<a .*>)?\s*(<img .* \/>)\s*(\/a>)?\s*<\/p>/iU', '\1\2\3', $content);
}
add_filter('the_content', 'ractopress_remove_img_ptags');
function easy_excerpt_length( $length ) {
	global $EasyExcerptLength;
	if ($EasyExcerptLength) {
    return $EasyExcerptLength;
	} else {
    return 50; //default value
    } }
	add_filter( 'excerpt_length', 'easy_excerpt_length', 999 );
	
	function easy_excerpt_more($more) {
       global $post;
	return '<a href="'. get_permalink($post->ID) . '" class="read-more">Read More</a>';
	}
	add_filter('excerpt_more', 'easy_excerpt_more');
// remove gallery shortcode styling
add_filter('gallery_style',
    create_function(
        '$css',
        'return preg_replace("#<style type=\'text/css\'>(.*?)</style>#s", "", $css);'
    )
);
        
?>